@@ -262,14 +262,14 @@ class ConnectionManager(QObject):
             self.show_information("Thumbnail fetch failed, internal error", False)
 
     ### GET FILE HANDLERS
-    def get_file(self, path, root, store_path, size, mime_type, sync_download = False):
+    def get_file(self, path, root, store_path, size, mime_type, sync_download = False, dropbox_icon = None):
         if not self.check_client:
             return
         file_name = path.split("/")[-1]
         dropbox_path = path[0:path.rfind("/")]
         if sync_download == False:
             self.show_information("Download queued\n" + file_name, None, 4000)
-        self.transfer_manager.handle_download(path, root, file_name, dropbox_path, store_path, size, mime_type, sync_download)
+        self.transfer_manager.handle_download(path, root, file_name, dropbox_path, store_path, size, mime_type, sync_download, dropbox_icon)
         
     def get_file_callback(self, resp, data, params):
         if resp != None and params[0] != None and params[1] != None:
