@@ -3,7 +3,7 @@
 import sys
 import os
 
-""" Crazy hack to instantiate QApplication in PR 1.3 """
+""" Grazy hack to instantiate QApplication in PR 1.3 """
 from PyQt4.QtGui import QApplication
 singleton_app = QApplication(sys.argv)
 
@@ -22,7 +22,6 @@ from logger import Logger
 from settings import ConfigHelper, SettingsWidget
 from transfers import SyncManager, TransferManager, TransferWidget
 
-
 """ Main programs controller, instantiates all the nessesary classes, starts ui and auth """
 
 class DropN900():
