@@ -1027,7 +1027,7 @@ class TransferManager(QObject):
             except KeyError:
                 self.logger.warning("Could not find widget for started transfer")
                 
-    def handle_download(self, path, root, file_name, dropbox_path, device_store_path, size, mime_type, sync_download):
+    def handle_download(self, path, root, file_name, dropbox_path, device_store_path, size, mime_type, sync_download, dropbox_icon = None):
         download = TransferWorker("Download")
         download.set_callable(self.client.get_file, root, path)
         download.set_callback(self.connection.get_file_callback, device_store_path, file_name)
@@ -1038,7 +1038,7 @@ class TransferManager(QObject):
             self.tranfer_to_widget[download] = self.sync_widget
         else:
             device_path = device_store_path[0:device_store_path.rfind("/")]
-            download_item = self.transfer_widget.add_download(file_name, dropbox_path, device_path, size, mime_type, sync_download)
+            download_item = self.transfer_widget.add_download(file_name, dropbox_path, device_path, size, mime_type, sync_download, dropbox_icon)
             self.tranfer_to_widget[download] = download_item
         
         self.queued_transfer_threads.append(download)
@@ -1183,12 +1183,12 @@ class TransferWidget(QMainWindow):
         self.layout_check()
         QWidget.showEvent(self, show_event)
         
-    def add_download(self, filename, from_path, to_path, size, mime_type, sync_download):
+    def add_download(self, filename, from_path, to_path, size, mime_type, sync_download, dropbox_icon = None):
         download_item = TransferItem(self, "Download", sync_download)
         icon = self.icon_download if not sync_download else self.icon_download_sync
         download_item.set_icon(icon, True)
         download_item.set_information(filename, from_path, to_path, size)
-        download_item.handle_mime_type(mime_type)
+        download_item.handle_mime_type(mime_type, dropbox_icon)
         
         self.ui.item_layout.insertWidget(0, download_item)
         download_item.show()
@@ -1447,7 +1447,7 @@ class TransferItem(QWidget):
             self.ui.content_frame.setStyleSheet("QFrame#content_frame{border: 0px;border-bottom: 1px solid grey;background-color: \
             qlineargradient(spread:pad, x1:0, y1:0.466182, x2:1, y2:1, stop:0 rgba(0, 0, 0, 255), stop:0.462312 rgba(11, 11, 64, 255), stop:1 rgba(22, 22, 22, 255));}")
 
-    def handle_mime_type(self, item_type):
+    def handle_mime_type(self, item_type, dropbox_icon = None):
         if item_type == None:
             self.ui.mime_icon.hide()
             self.ui.label_filename.setIndent(0)
@@ -1456,29 +1456,42 @@ class TransferItem(QWidget):
         base_type = item_type.split("/")[0]
         # item type
         icon = None
-        if item_type == "folder":
-            icon = QIcon(base_path + "folder.png")
-        elif item_type == "folder_opened":
-            icon = QIcon(base_path + "folder_open.png")
-        elif item_type == "n900":
-            icon = QIcon(base_path + "n900_small.png")
-        elif item_type == "size":
-            icon = QIcon(base_path + "calculator.png")
-        elif item_type == "time":
-            icon = QIcon(base_path + "clock.png")
-        elif item_type == "deleted_item":
-            icon = QIcon(base_path + "cancel.png")
-        elif item_type == "deleted_folder":
-            icon = QIcon(base_path + "folder_delete.png")
-        # base type (from mimetype pre /)
-        elif base_type == "text":
-            icon = QIcon(base_path + "document_edit.png")
-        elif base_type == "image":
-            icon = QIcon(base_path + "picture.png")
-        elif base_type == "application":
-            icon = QIcon(base_path + "applications.png")
+        if dropbox_icon == None:
+            if item_type == "folder":
+                icon = QIcon(base_path + "folder.png")
+            elif item_type == "folder_opened":
+                icon = QIcon(base_path + "folder_open.png")
+            elif item_type == "n900":
+                icon = QIcon(base_path + "n900_small.png")
+            elif item_type == "size":
+                icon = QIcon(base_path + "calculator.png")
+            elif item_type == "time":
+                icon = QIcon(base_path + "clock.png")
+            elif item_type == "deleted_item":
+                icon = QIcon(base_path + "cancel.png")
+            elif item_type == "deleted_folder":
+                icon = QIcon(base_path + "folder_delete.png")
+            # base type (from mimetype pre /)
+            elif base_type == "text":
+                icon = QIcon(base_path + "document_edit.png")
+            elif base_type == "image":
+                icon = QIcon(base_path + "picture.png")
+            elif base_type == "application":
+                icon = QIcon(base_path + "applications.png")
+            else:
+                icon = QIcon(base_path + "document.png")
         else:
-            icon = QIcon(base_path + "document.png")
+            dropbox_icon_path_48 = base_path + "dropbox/48x48/" + dropbox_icon + "48.gif"
+            dropbox_icon_path_16 = base_path + "dropbox/16x16/" + dropbox_icon + ".gif"
+            if dropbox_icon == "page_white_compressed":
+                icon = QIcon(base_path + "dropbox/48x48/package48.gif")
+            elif os.path.exists(dropbox_icon_path_48):
+                icon = QIcon(dropbox_icon_path_48)
+            elif os.path.exists(dropbox_icon_path_16):
+                icon = QIcon(dropbox_icon_path_16)
+            else:
+                icon = QIcon(base_path + "document.png")
+
         # set icon
         if icon != None:
             self.ui.mime_icon.setPixmap(icon.pixmap(20,20))
