@@ -351,7 +351,7 @@ class UiController:
                 self.show_note("Cannot download, destination " + self.datahandler.get_data_dir_path() + " does not exist. Please set a new folder in settings.")
                 return
             store_path = self.datahandler.get_data_dir_path() + data.name
-        self.controller.connection.get_file(data.path, data.root, store_path, data.get_size(), data.mime_type)
+        self.controller.connection.get_file(data.path, data.root, store_path, data.get_size(), data.mime_type, dropbox_icon = data.icon)
         
     def item_upload(self):
         data = self.get_selected_data()
@@ -621,6 +621,9 @@ class TreeController:
         self.tree.itemClicked.connect(self.item_clicked)
         self.tree.itemExpanded.connect(self.item_expanded)
         self.tree.itemCollapsed.connect(self.item_collapsed)
+        
+        # Icon cache
+        self.icon_cache = {}
 
     def setup(self, connection):
         self.connection = connection
@@ -759,7 +762,7 @@ class TreeController:
             child.setTextAlignment(1, Qt.AlignRight|Qt.AlignVCenter)
             child.setFirstColumnSpanned(True)
             # Set icon with mime type, and folder indicator
-            self.set_icon(item.mime_type, child)
+            self.set_icon(item.mime_type, child, dropbox_icon = item.icon)
             if item.is_folder():
                 child.setChildIndicatorPolicy(QTreeWidgetItem.ShowIndicator)
             # Set tree item to item data
@@ -827,37 +830,53 @@ class TreeController:
             item.removeChild(child)
             del child
 
-    def set_icon(self, item_type, tree_item, index = 0, label = None):
+    def set_icon(self, item_type, tree_item, index = 0, label = None, dropbox_icon = None):
         base_path = self.controller.datahandler.app_root + "ui/icons/"
         base_type = item_type.split("/")[0]
-        # item type
-        if item_type == "folder":
-            icon = QIcon(base_path + "folder.png")
-        elif item_type == "folder_opened":
-            icon = QIcon(base_path + "folder_open.png")
-        elif item_type == "n900":
-            icon = QIcon(base_path + "n900_small.png")
-        elif item_type == "size":
-            icon = QIcon(base_path + "calculator.png")
-        elif item_type == "time":
-            icon = QIcon(base_path + "clock.png")
-        elif item_type == "deleted_item":
-            icon = QIcon(base_path + "cancel.png")
-        elif item_type == "deleted_folder":
-            icon = QIcon(base_path + "folder_delete.png")
-        # base type (from mimetype pre /)
-        elif base_type == "text":
-            icon = QIcon(base_path + "document_edit.png")
-        elif base_type == "image":
-            icon = QIcon(base_path + "picture.png")
-        elif base_type == "application":
-            icon = QIcon(base_path + "applications.png")
-        else:
-            icon = QIcon(base_path + "document.png")
-        if tree_item != None:
+        icon = None
+        
+        # Check icon cache
+        try:
+            if dropbox_icon == None:
+                icon = self.icon_cache[item_type]
+            else:
+                icon = self.icon_cache[dropbox_icon]
+        except:
+            icon = None
+            
+        # Resolve icon if needed
+        if icon == None:
+            if item_type == "folder":
+                icon = QIcon(base_path + "folder.png")
+            elif item_type == "folder_opened":
+                icon = QIcon(base_path + "folder_open.png")
+            elif item_type == "deleted_item":
+                icon = QIcon(base_path + "cancel.png")
+            elif item_type == "deleted_folder":
+                icon = QIcon(base_path + "folder_delete.png")
+            elif item_type == "application/x-msdos-program" or item_type == "application/x-debian-package":
+                icon = QIcon(base_path + "dropbox/48x48/page_white_gear48.gif")
+            elif dropbox_icon != None:
+                dropbox_icon_path_48 = base_path + "dropbox/48x48/" + dropbox_icon + "48.gif"
+                dropbox_icon_path_16 = base_path + "dropbox/16x16/" + dropbox_icon + ".gif"
+                if dropbox_icon == "page_white_compressed":
+                    icon = QIcon(base_path + "dropbox/48x48/package48.gif")
+                elif os.path.exists(dropbox_icon_path_48):
+                    icon = QIcon(dropbox_icon_path_48)
+                elif os.path.exists(dropbox_icon_path_16):
+                    icon = QIcon(dropbox_icon_path_16)
+                else:
+                    icon = QIcon(base_path + "document.png")
+                self.icon_cache[dropbox_icon] = icon
+                
+            if dropbox_icon == None and icon != None:
+                self.icon_cache[item_type] = icon
+        
+        # Set icon
+        if tree_item != None and icon != None:
             tree_item.setIcon(index, icon)
-        elif label != None:
-            label.setPixmap(icon.pixmap(24,24))        
+        elif label != None and icon != None:
+            label.setPixmap(icon.pixmap(24,24))
 
     def update_action_buttons(self, is_folder, is_root = False):
         self.controls_ui.button_download.setEnabled(not is_folder)
@@ -906,7 +925,7 @@ class TreeController:
         # Update ui with selected data
         self.controls_ui.selected_name_label.setText(data.get_name())
         self.controls_ui.modified_label.setText(data.modified)
-        self.set_icon(data.mime_type, None, None, self.controls_ui.selected_icon_label)
+        self.set_icon(data.mime_type, None, None, self.controls_ui.selected_icon_label, data.icon)
         self.update_action_buttons(data.is_folder(), True if data.path == "" else False)
 
         # Update thumbnail if its available
